@@ -20,6 +20,8 @@ export var UPDATE_ZOOM_SCALE = 'UPDATE_ZOOM_SCALE';
 export var TOGGLE_SNAP = 'TOGGLE_SNAP';
 export var CHANGE_CATALOG_PAGE = 'CHANGE_CATALOG_PAGE';
 export var GO_BACK_TO_CATALOG_PAGE = 'GO_BACK_TO_CATALOG_PAGE';
+export var THROW_ERROR = 'THROW_ERROR';
+export var THROW_WARNING = 'THROW_WARNING';
 
 // ACTIONS viewer2D
 export var SELECT_TOOL_ZOOM_IN = 'SELECT_TOOL_ZOOM_IN';
@@ -99,7 +101,9 @@ export var PROJECT_ACTIONS = {
   UPDATE_ZOOM_SCALE: UPDATE_ZOOM_SCALE,
   TOGGLE_SNAP: TOGGLE_SNAP,
   CHANGE_CATALOG_PAGE: CHANGE_CATALOG_PAGE,
-  GO_BACK_TO_CATALOG_PAGE: GO_BACK_TO_CATALOG_PAGE
+  GO_BACK_TO_CATALOG_PAGE: GO_BACK_TO_CATALOG_PAGE,
+  THROW_ERROR: THROW_ERROR,
+  THROW_WARNING: THROW_WARNING
 };
 
 export var VIEWER2D_ACTIONS = {
