@@ -286,6 +286,8 @@ export class State extends Record({
   drawingSupport: new Map(),
   draggingSupport: new Map(),
   rotatingSupport: new Map(),
+  errors: new List(),
+  warnings: new List(),
   misc: new Map()   //additional info
 }, 'State') {
   constructor(json = {}) {
