@@ -4,7 +4,7 @@ import {Vertex} from '../models';
 import IDBroker from './id-broker';
 import NameGenerator from './name-generator';
 import * as Geometry from './geometry';
-import calculateInnerCyles from './graph-inner-cycles';
+import calculateInnerCyles, {isClockWiseOrder} from './graph-inner-cycles';
 
 const flatten = list => list.reduce((a, b) => a.concat(Array.isArray(b) ? flatten(b) : b), []);
 
@@ -494,6 +494,21 @@ export function detectAndUpdateAreas(layer, catalog) {
   let innerCyclesByVerticesID = new List(innerCyclesByVerticesArrayIndex)
     .map(cycle => new List(cycle.map(vertexIndex => verticesArrayIndex_to_vertexID[vertexIndex])));
 
+  // All area vertices should be ordered in counterclockwise order
+  innerCyclesByVerticesID = innerCyclesByVerticesID.withMutations(innerCyclesByVerticesID => {
+    innerCyclesByVerticesID.forEach((innerCycle, index) => {
+      let innerCycleWithCoords = innerCycle.map(vertexID => {
+        return new Map({
+          x: layer.vertices.get(vertexID).x,
+          y: layer.vertices.get(vertexID).y
+        });
+      });
+      if (isClockWiseOrder(innerCycleWithCoords)) {
+        innerCyclesByVerticesID.set(index, innerCyclesByVerticesID.get(index).reverse());
+      }
+    });
+  });
+
   let areaIDs = [];
 
   layer = layer.withMutations(layer => {
